@@ -17,6 +17,9 @@ class BehaviorBase : public ReferenceCounter, public EventListener {
 	virtual void DoStart() { AddReference(); started=true;}
 	//! By default, subtracts from the reference counter, and deletes if zero @note you should still call this when you override this @warning call this at the end of your DoStop(), not beginning (it might @c delete @c this )
 	virtual void DoStop() { started=false; RemoveReference(); }
+	//! Allows you to get away with not supplying a processEvent() function for the EventListener interface.  By default, does nothing.
+	virtual void processEvent(const EventBase& /*event*/) {};
+
 	
 	//! Used to identify the behavior in menus and such
 	virtual const char* getName() const =0;
@@ -33,10 +36,10 @@ class BehaviorBase : public ReferenceCounter, public EventListener {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2003/01/10 05:08:14 $
+ * $Date: 2003/04/18 05:15:05 $
  */
 
 #endif
