@@ -3,6 +3,12 @@
 #include "Motion/LedMC.h"
 #include <iomanip>
 
+void MenuControl::clearSlots() {
+	for(unsigned int i=0; i<options.size(); i++)
+		delete options[i];
+	options.clear();
+}
+
 ControlBase * MenuControl::activate(MotionManager::MC_ID display) {
 	display_id=display;
 	refresh();
@@ -158,21 +164,22 @@ ControlBase* MenuControl::doReadStdIn() {
 	}
 }
 
-#ifdef CONSOLE_VT100
 void MenuControl::clearMenu() {
+#ifdef CONSOLE_VT100
 	cout << "\r\33[" << (options.size()+1) << 'A'; //moves cursor up to beginning of menu
 	cout << "\33[J"; //clears to end of screen
-}
 #endif
+}
+
 
 /*! @file
  * @brief Implements MenuControl, the main Control for the heirarchical menu structure
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2003/03/15 03:44:39 $
+ * $Date: 2003/04/30 03:55:49 $
  */
 
