@@ -13,9 +13,7 @@ class MenuControl : public ControlBase {
 	MenuControl(const std::string& n) : ControlBase(n), cur(0), options(), display_id(MotionManager::invalid_MC_ID), doRewrite(false) {} //!< constructor, see ControlBase::ControlBase(const std::string& n)
 	virtual ~MenuControl() {
 		deactivate();
-		for(unsigned int i=0; i<options.size(); i++)
-			delete options[i];
-		options.clear();
+		clearSlots();
 	} //!< destructor
 
 	virtual ControlBase * activate(MotionManager::MC_ID display);
@@ -28,6 +26,7 @@ class MenuControl : public ControlBase {
 	unsigned int slotsSize() const { return options.size(); } //!< returns the number of options available
 	void setSlot(unsigned int i,ControlBase* o); //!< sets @a i'th element of ::options to @a o
 	void pushSlot(ControlBase* o); //!< sets next unused element of ::options to @a o
+	void clearSlots(); //!< deletes each slot item and clears the slots
 
 	virtual ControlBase* doSelect();
 	virtual ControlBase* doNextItem();
@@ -40,9 +39,8 @@ class MenuControl : public ControlBase {
 	virtual ControlBase* getCurControl() { return options[cur]; } //!< returns the currently selected control
 	
  protected:
-#ifdef CONSOLE_VT100
 	virtual void clearMenu();
-#endif
+
 	unsigned int cur; //!< index of current selection
 	std::vector<ControlBase*> options; //!< vector of controls to select from
 	MotionManager::MC_ID display_id; //!< LedMC to use for displaying selection
@@ -56,10 +54,10 @@ class MenuControl : public ControlBase {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2003/03/03 01:18:12 $
+ * $Date: 2003/04/30 03:55:49 $
  */
 
 #endif
