@@ -16,6 +16,10 @@
  *  of switching the ears back manually using a PostureMC */
 class BatteryMonitorBehavior : public BehaviorBase {
 public:
+	static const unsigned int max_t=5000; //!< max time between ear flips when at "high power" mark
+	static const unsigned int high_power_p=25; //!< percent of 100 which is point at which to begin warning
+	static const unsigned int no_power_p=15; //!< percent of 100 at which power will fail (approximate!)
+
 	//! constructor
 	BatteryMonitorBehavior() : BehaviorBase(), pose(NULL), pose_id(MotionManager::invalid_MC_ID), led_id(MotionManager::invalid_MC_ID) {}
 	//! destructor
@@ -90,22 +94,24 @@ public:
 	virtual const char* getName() const { return (isActive()?"#BatteryMonitorBehavior":"-BatteryMonitorBehavior"); }
 
 	//! returns true if the warning should be active (power remaining less than 40%, no external power, but also checks that a power update has been received)
-	static bool shouldWarn() { return state!=NULL && state->powerFlags[PowerSourceID::BatteryConnectSID] && (state->sensors[PowerRemainOffset]<=.15 || state->powerFlags[PowerSourceID::LowPowerWarnSID]) && !state->powerFlags[PowerSourceID::ExternalPowerSID]; }
+	static bool shouldWarn() { return state!=NULL && state->powerFlags[PowerSourceID::BatteryConnectSID] && (state->sensors[PowerRemainOffset]*100<=high_power_p || state->powerFlags[PowerSourceID::LowPowerWarnSID]) && !state->powerFlags[PowerSourceID::ExternalPowerSID]; }
 
 protected:
 	//! adds a pose and a timer to get the ears flipping
 	void startWarning() {
+		cout << "LOW BATTERY" << endl;
 		pose_id=motman->addMotion(SharedObject<PostureMC>(),MotionManager::kEmergencyPriority+1);
 		pose=(PostureMC*)motman->peekMotion(pose_id);
 		SharedObject<LedMC> led;
 		led->displayPercent(state->sensors[PowerRemainOffset],LedEngine::major,LedEngine::major);
 		led_id=motman->addMotion(led,MotionManager::kEmergencyPriority+1);
 		for(unsigned int i=EarOffset; i<EarOffset+NumEarJoints; i++)
-			pose->setOutputCmd(i,!state->outputs[EarOffset]);
+			pose->setOutputCmd(i,!state->outputs[i]);
 		erouter->addTimer(this,2,128,false);
 	}
 	//! removes pose, in case battery magically charges
 	void stopWarning() {
+		cout << "BATTERY GOOD" << endl;
 		motman->removeMotion(pose_id);
 		motman->removeMotion(led_id);
 		led_id=pose_id=MotionManager::invalid_MC_ID;
@@ -115,10 +121,9 @@ protected:
 	}
 	//! makes the ears flip more rapidly as power declines.  Flips back and forth once every 15 seconds at 15%, down to flipping constantly at 5%.
 	unsigned int calcFlipDelay() {
-		unsigned int max_t=5000;
-		double high_power=.15;
-		double no_power=.05;
-		double cur_power=state->sensors[PowerRemainOffset];
+		const float high_power=high_power_p/100.0;
+		const float no_power=no_power_p/100.0;
+		float cur_power=state->sensors[PowerRemainOffset];
 		if(cur_power<no_power)
 			return 0;
 		return (unsigned int)(max_t*(cur_power-no_power)/(high_power-no_power));
@@ -137,10 +142,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2003/03/09 02:45:20 $
+ * $Date: 2003/04/28 01:10:58 $
  */
 
 #endif
