@@ -13,20 +13,20 @@ const char* const EventBase::EventGeneratorNames[numEGIDs] = {
 	"Timer",
 	"StateMachine",
 	"Locomotion",
-  "TextMsg",
+	"TextMsg",
 	"EStop",
 	"MotionManager"
 };
 
 
 EventBase::EventBase()
-	: LoadSave(), stim_id(""), magnitude(0), timestamp(get_time()), nameisgen(true), genID(unknownEGID), typeID(statusETID), sourceID((unsigned int)-1), duration(0)
+	: LoadSave(), stim_id(), magnitude(0), timestamp(get_time()), nameisgen(true), genID(unknownEGID), typeID(statusETID), sourceID((unsigned int)-1), duration(0)
 {
 	genName();
 }
 
 EventBase::EventBase(EventGeneratorID_t gid, unsigned int sid, EventTypeID_t tid, unsigned int dur)
-	: LoadSave(), stim_id(""), magnitude(0), timestamp(get_time()), nameisgen(true), genID(gid), typeID(tid), sourceID(sid), duration(dur)
+	: LoadSave(), stim_id(), magnitude(0), timestamp(get_time()), nameisgen(true), genID(gid), typeID(tid), sourceID(sid), duration(dur)
 {
 	genName();
 	if(tid==deactivateETID)
@@ -115,10 +115,10 @@ EventBase::genName() {
 	if(!nameisgen)
 		return;
 	if(genID<numEGIDs) {
-		stim_id="Evt_";
+		stim_id=std::string("Evt_");
 		stim_id+=EventGeneratorNames[genID];
 	} else {
-		stim_id="Evt_InvalidGen";
+		stim_id=std::string("Evt_InvalidGen");
 		stim_id+=genID; 
 	}
 	stim_id+="::";
@@ -169,9 +169,9 @@ EventBase::genName() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2003/04/09 03:33:51 $
+ * $Date: 2003/04/25 18:22:39 $
  */
 
