@@ -230,9 +230,10 @@ void EventRouter::EventMapper::clean() {
 		for(unsigned int et=0; et<EventBase::numETIDs; et++) {
 			SIDtoListenerVectorMap_t* mapping=filteredevents[eg][et];
 			if(mapping!=NULL) { // if there are subscribers to this egid/etid
-				if(mapping->size()==0)
+				if(mapping->size()==0) {
 					delete mapping;
-				filteredevents[eg][et]=NULL;
+					filteredevents[eg][et]=NULL;
+				}
 			}
 		}
 	}
@@ -316,10 +317,10 @@ void EventRouter::EventMapper::getMapping(const EventBase& e, std::vector<T*>& l
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2003/04/06 20:57:43 $
+ * $Date: 2003/04/25 22:25:37 $
  */
 
 
