@@ -10,14 +10,14 @@
 class DynamicMotionSequence : public MotionSequence {
 public:
 	//!constructor
-	DynamicMotionSequence() : MotionSequence(), moves(), erased() {}
+	DynamicMotionSequence() : MotionSequence(), moves(), erased() {clear();}
 	//!constructor, loads from a file and then resets the playtime to beginning and begins to play
 	explicit DynamicMotionSequence(const char* filename) : MotionSequence(), moves(), erased() {clear();LoadFile(filename);setPlayTime(1);}
 	//!destructor
 	virtual ~DynamicMotionSequence() {}
 
 	// I put this here because i want direct access to moves so it'll be faster
-	void planJointCmds(unsigned int i, JointCmd frames[NumFrames]) {
+/*	void planJointCmds(unsigned int i, JointCmd frames[NumFrames]) {
 		Move_idx_t prev=prevs[i],next=nexts[i];
 		frames[0]=getJointCmd(i);
 		for(unsigned int t=playtime+FrameTime,j=1;j<NumFrames;j++,t+=FrameTime) {
@@ -27,14 +27,42 @@ public:
 			else
 				frames[j]=unusedJoint;
 		}
-	}
+	}*/
+	
 
+	virtual int updateOutputs() {
+		MotionSequence::updateOutputs();
+		if(!isPlaying()) {
+			for(unsigned int i=0; i<NumOutputs; i++) //just copies getOutputCmd(i) across frames
+				motman->setOutput(this,i,getOutputCmd(i));
+		} else {
+			for(unsigned int i=0; i<NumOutputs; i++) { //fill out the buffer of commands for smoother movement
+				Move_idx_t prev=prevs[i],next=nexts[i];
+				OutputCmd frames[NumFrames];
+				frames[0]=getOutputCmd(i);
+				for(unsigned int t=playtime+FrameTime,j=1;j<NumFrames;j++,t+=FrameTime) {
+					setRange(t,prev,next);
+					if(next!=invalid_move)
+						calcOutput(frames[j],t,moves[prev],moves[next]);
+					else
+						frames[j].unset();
+				}
+				motman->setOutput(this,i,frames);
+			}
+		}
+		return NumOutputs;
+		//		if(i<NumLegJointss)
+		//			log.push_back(logent(get_time(),playtime,i,frames));
+	}
+	
 	virtual void clear() {
 		moves.clear();
 		erased.clear();
 		for(unsigned int i=0; i<NumOutputs; i++) {
 			moves.push_back(Move());
-			moves.back().cmd=unusedJoint;
+			moves.back().cmd.unset();
+			moves.back().next=invalid_move;
+			moves.back().prev=invalid_move;
 			prevs[i]=starts[i]=moves.size()-1;
 			nexts[i]=invalid_move;
 		}
@@ -84,10 +112,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.2 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.3 $
  * $State: Exp $
- * $Date: 2003/01/09 02:02:58 $
+ * $Date: 2003/04/25 18:22:39 $
  */
 
 #endif
