@@ -14,17 +14,27 @@ const float MotionManager::kStdPriority        = 10;
 const float MotionManager::kHighPriority       = 50;
 const float MotionManager::kEmergencyPriority  = 100;
 
+#ifndef PLATFORM_APERIOS
+using std::cout;
+using std::endl;
+#endif
+
 
 //! just for convenience
 typedef unsigned int uint;
 
 MotionManager::MotionManager()
-	: pidchanges(),cmdlist(),cur_cmd(invalid_MC_ID),MMlock(),numAcc(0)
+	: pidchanges(),cmdlist(),cur_cmd(invalid_MC_ID),MMlock()
+#ifdef PLATFORM_APERIOS
+	,numAcc(0)
+#endif
 {
 	for(uint x=0; x<NumOutputs; x++)
 		cmdSums[x]=0;
 }
 
+#ifdef PLATFORM_APERIOS
+
 void
 MotionManager::InitAccess(OSubject* subj) {
 	if(numAcc==MAX_ACCESS) {
@@ -43,8 +53,12 @@ MotionManager::InitAccess(OSubject* subj) {
 	MMlock.release();
 }
 
+#endif //PLATFORM_APERIOS
+
 void
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd& cmd) {
+    if (output >= NumOutputs) return; 
+
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
 	if(cur_cmd==invalid_MC_ID) {
@@ -65,6 +79,8 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
 
 void
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd& cmd, unsigned int frame) {
+    if (output >= NumOutputs) return; 
+
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
 	if(cur_cmd==invalid_MC_ID) {
@@ -84,6 +100,8 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
 
 void 
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd ocmds[NumFrames]) {
+    if (output >= NumOutputs) return; 
+
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
 	if(cur_cmd==invalid_MC_ID) {
@@ -104,6 +122,8 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
 
 void
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputPID& pid) {
+    if (output >= NumOutputs) return; 
+
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
 	if(cur_cmd==invalid_MC_ID) {
@@ -122,6 +142,8 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
 
 void
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd& cmd, const OutputPID& pid) {
+    if (output >= NumOutputs) return; 
+
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
 	if(cur_cmd==invalid_MC_ID) {
@@ -144,6 +166,8 @@ MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const
 
 void
 MotionManager::setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd ocmds[NumFrames], const OutputPID& pid) {
+    if (output >= NumOutputs) return; 
+
 	if(caller==NULL || caller->getID()!=cur_cmd)
 		func_begin();
 	if(cur_cmd==invalid_MC_ID) {
@@ -191,11 +215,11 @@ MotionManager::getOutputs(float outputs[NumFrames][NumOutputs]) {
 		cmdstates[output].clear();
 
 	//	std::cout << "UPDATE..." << std::flush;
-	list<MC_ID> unlocked;
+	std::list<MC_ID> unlocked;
 	for(MC_ID it=begin(); it!=end(); it=next(it)) // check out all the MotionCommands (only one at a time tho)
 		unlocked.push_back(it);
 	while(unlocked.size()>0) { // keep cycling through all the locks we didn't get
-		for(list<MC_ID>::iterator it=unlocked.begin(); it!=unlocked.end(); ) {
+		for(std::list<MC_ID>::iterator it=unlocked.begin(); it!=unlocked.end(); ) {
 			MotionCommand* mc=checkoutMotion(*it,false);
 			if(mc==NULL)
 				it++; //we didn't get a lock, skip it (we'll keep looping until we get it)
@@ -209,7 +233,7 @@ MotionManager::getOutputs(float outputs[NumFrames][NumOutputs]) {
 					mc->updateOutputs(); // the MotionCommand should make calls to setOutput from within here
 				checkinMotion(*it); // release lock, done with motion
 				// remove id from list of unprocessed motioncommands
-				list<MC_ID>::iterator rem=it++;
+				std::list<MC_ID>::iterator rem=it++;
 				unlocked.erase(rem);
 			}
 		}
@@ -254,9 +278,11 @@ MotionManager::getOutputs(float outputs[NumFrames][NumOutputs]) {
 				for(;curstatelist[ent].priority==curp; ent=curstatelist.next(ent)) {
 					//weighted average within priority level
 					float curweight=curstatelist[ent].frames[frame].weight;
-					ASSERT(curweight>=0,"negative output weights are illegal")
-					if(curweight<0) //negative weights are illegal
+					ASSERT(curweight>=0,"negative output weights are illegal");
+					if(curweight<0) { //negative weights are illegal
+						cout << "weight=" << curweight << endl;
 						curweight=0;
+					}
 					curcmd.value+=curstatelist[ent].frames[frame].value*curweight;
 					curcmd.weight+=curweight;
 					if(curweight<1)
@@ -340,6 +366,8 @@ MotionManager::updateWorldState() {
 		state->outputs[output]=cmdSums[output];
 }
 
+#ifdef PLATFORM_APERIOS
+
 bool
 MotionManager::updatePIDs(OPrimitiveID primIDs[NumOutputs]) {
 	bool dirty=!pidchanges.empty();
@@ -453,6 +481,8 @@ MotionManager::receivedMsg(const ONotifyEvent& event) {
 	func_end();
 }
 
+#endif //PLATFORM_APERIOS
+
 MotionCommand *
 MotionManager::checkoutMotion(MC_ID mcid,bool block) {
 	//cout << "checkout..." << flush;
@@ -498,16 +528,19 @@ MotionManager::removeMotion(MC_ID mcid) {
 	checkoutMotion(mcid,true);
 	cmdlist[mcid].baseaddrs[_MMaccID]->DoStop();
 	erouter->postEvent(new EventBase(EventBase::motmanEGID,mcid,EventBase::deactivateETID,00));
+#ifdef PLATFORM_APERIOS
 	MotionManagerMsg dmsg;
 	dmsg.setDelete(mcid);
 	subjs[_MMaccID]->SetData(&dmsg,sizeof(dmsg));
 	subjs[_MMaccID]->NotifyObservers();
 	cmdlist[mcid].rcr[_MMaccID]->RemoveReference();
+#endif //PLATFORM_APERIOS
 	push_free(mcid);
 	checkinMotion(mcid);
 	func_end();
 }
 
+
 /*! Note that we don't actually set the PIDs in the system here, we just queue them up.
  *  PID changes seem to be an expensive operation, so may only want to clear the queue
  *  at some reduced rate (although that's not actually currently implemented, so right
@@ -549,9 +582,13 @@ MotionManager::MC_ID
 MotionManager::skip_ahead(MC_ID mcid) const {
 	// this is in case a new motion has been added, but the current
 	// process hasn't received its own copy yet, so should skip over them
+#ifdef PLATFORM_APERIOS
 	while(mcid!=cmdlist.end() && cmdlist[mcid].rcr[_MMaccID]==NULL)
 		mcid=cmdlist.next(mcid);
 	return mcid;
+#else
+	return cmdlist.next(mcid);
+#endif
 }
 
 MotionManager::OutputState::OutputState()
@@ -596,10 +633,10 @@ MotionManager::OutputState::OutputState(unsigned int /*out*/, float pri, MC_ID m
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.17 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.20 $
  * $State: Exp $
- * $Date: 2003/04/09 03:33:57 $
+ * $Date: 2003/04/27 23:57:43 $
  */
 
 
