@@ -5,17 +5,22 @@
 #include "MotionCommand.h"
 #include "OutputCmd.h"
 #include "OutputPID.h"
+#include "Shared/RobotInfo.h"
+#include "Shared/ListMemBuf.h"
+#include "Shared/MutexLock.h"
+
+#ifdef PLATFORM_APERIOS
 #include "Shared/SharedObject.h"
 #include "MotionManagerMsg.h"
-#include "Shared/RobotInfo.h"
-#include "Shared/MutexLock.h"
-#include "Shared/ListMemBuf.h"
+#endif
 
+#ifdef PLATFORM_APERIOS
 #include <OPENR/OPENR.h>
 #include <OPENR/OPENRAPI.h>
 #include <OPENR/OSubject.h>
 #include <OPENR/ObjcommEvent.h>
 #include <OPENR/OObject.h>
+#endif
 
 //! The purpose of this class is to serialize access to the MotionCommands and simplify their sharing between memory spaces
 /*! Since MotionObject and MainObject run as separate processes, they could potentially try to access the
@@ -61,8 +66,11 @@ public:
 	static const MC_ID invalid_MC_ID=(MC_ID)-1; //!< for errors and undefined stuff
 
 	MotionManager();                            //!< Constructor, sets all the outputs to 0
+
+#ifdef PLATFORM_APERIOS
 	void InitAccess(OSubject* subj);            //!< @b LOCKS @b MotionManager Everyone who is planning to use the MotionManager needs to call this before they access it or suffer a horrible fate
 	void receivedMsg(const ONotifyEvent& event); //!< @b LOCKS @b MotionManager This gets called by an OObject when it receives a message from one of the other OObject's MotionManagerComm Subject
+#endif
 
 	//!@name MotionCommand Safe
 	void setOutput(const MotionCommand* caller, unsigned int output, const OutputCmd& cmd); //!< @b LOCKS @b MotionManager Requests a value be set for the specified output, copies cmd across frames
@@ -93,10 +101,12 @@ public:
 
 	//!@name MotionCommand Unsafe
 	//@{
+#ifdef PLATFORM_APERIOS
 	MC_ID addMotion(const SharedObjectBase& sm); //!< @b LOCKS @b MotionManager Creates a new MotionCommand, automatically sharing it between processes (there is some lag time here)
 	MC_ID addMotion(const SharedObjectBase& sm, float priority); //!< @b LOCKS @b MotionManager allows a quick way to set a priority level of a new MotionCommand
 	MC_ID addMotion(const SharedObjectBase& sm, bool autoprune); //!< @b LOCKS @b MotionManager allows a quick was to set the autoprune flag
 	MC_ID addMotion(const SharedObjectBase& sm, float priority, bool autoprune); //!< @b LOCKS @b MotionManager Call one of these to add a MotionCommand to the MotionManager, using the SharedObject class
+#endif //PLATFORM_APERIOS
 	void removeMotion(MC_ID mcid); //!< @b LOCKS @b MotionManager removes the specified MotionCommand
 	//@}
 
@@ -109,7 +119,9 @@ public:
 	//@{
 	void getOutputs(float outputs[NumFrames][NumOutputs]);  //!< @b LOCKS @b MotionManager called by MotionObject to fill in the output values for the next ::NumFrames frames (only MotoObj should call this...)
 	void updateWorldState();                                //!< call this when you want MotionManager to set the WorldState to reflect what things should be for unsensed outputs (LEDs, ears) (only MotoObj should be calling this...)
+#ifdef PLATFORM_APERIOS
 	bool updatePIDs(OPrimitiveID primIDs[NumOutputs]);      //!< call this when you want MotionManager to update modified PID values, returns true if changes made (only MotoObj should be calling this...)
+#endif
 	//@}
 
 	//! holds the full requested value of an output
@@ -170,11 +182,15 @@ protected:
 		CommandEntry() : lastAccessor((unsigned short)-1),lock(),priority(MotionManager::kStdPriority) {
 			for(unsigned int i=0; i<MAX_ACCESS; i++) {
 				baseaddrs[i]=NULL;
+#ifdef PLATFORM_APERIOS
 				rcr[i]=NULL;
+#endif
 			}
 		}
 		MotionCommand * baseaddrs[MAX_ACCESS]; //!< for each accessor, the base address of the motion command
+#ifdef PLATFORM_APERIOS
 		RCRegion * rcr[MAX_ACCESS];            //!< for each accessor the shared memory region that holds the motion command
+#endif
 		accID_t lastAccessor;                  //!< the ID of the last accessor to touch the command (which implies if it wants to touch this again, we don't have to convert again)
 		MutexLock<MAX_ACCESS> lock;            //!< a lock to maintain mutual exclusion
 		float priority;                        //!< MotionCommand's priority level
@@ -196,8 +212,10 @@ protected:
 	float cmdSums[NumOutputs];             //!<Holds the final values for the outputs of the last frame generated
 	OutputCmd cmds[NumOutputs];            //!<Holds the weighted values and total weight for the outputs of the last frame
 
+#ifdef PLATFORM_APERIOS
 	accID_t numAcc;                        //!<The number of accessors who have registered with InitAccess()
 	OSubject* subjs[MAX_ACCESS];           //!<The OSubject for each process (accessor) on which it should be broadcast when a command is added
+#endif
 
 	static unsigned int _MMaccID;          //!<Stores the accessor for the current process
 
@@ -214,10 +232,10 @@ extern MotionManager * motman;
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.12 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2003/03/09 02:45:23 $
+ * $Date: 2003/04/25 18:22:40 $
  */
 
 #endif
