@@ -40,6 +40,7 @@ unsigned int MotionSequence::getBinSize() const {
 	char buf[128];
 	unsigned int len=128;
 	unsigned int used=strlen("#MSq\n");
+	used+=snprintf(buf,len,isSaveRadians()?"radians\n":"degrees\n");
 	unsigned int t=0;
 	Move_idx_t tprevs[NumOutputs];
 	Move_idx_t tnexts[NumOutputs];
@@ -47,12 +48,12 @@ unsigned int MotionSequence::getBinSize() const {
 		tnexts[i]=getKeyFrame(tprevs[i]=starts[i]).next;
 	while(t!=-1U) {
 		for(unsigned int i=0; i<NumOutputs; i++) {
-			if(getKeyFrame(tprevs[i]).cmd.weight!=0 && getKeyFrame(tprevs[i]).starttime==t) {
+			if((t!=0 || getKeyFrame(tprevs[i]).cmd.weight!=0) && getKeyFrame(tprevs[i]).starttime==t) {
 				if(getKeyFrame(tprevs[i]).cmd.weight==1) {
 					if(t!=0)
-						used+=snprintf(buf,len,"%s\t%g\n",outputNames[i],getKeyFrame(tprevs[i]).cmd.value);
+						used+=snprintf(buf,len,"%s\t%g\n",outputNames[i],getKeyFrame(tprevs[i]).cmd.value/loadSaveMode);
 				} else
-					used+=snprintf(buf,len,"%s\t%g\t%g\n",outputNames[i],getKeyFrame(tprevs[i]).cmd.value,getKeyFrame(tprevs[i]).cmd.weight);
+					used+=snprintf(buf,len,"%s\t%g\t%g\n",outputNames[i],getKeyFrame(tprevs[i]).cmd.value/loadSaveMode,getKeyFrame(tprevs[i]).cmd.weight);
 			}
 		}
 		unsigned int last=t;
@@ -91,8 +92,9 @@ unsigned int MotionSequence::LoadBuffer(const char buf[], unsigned int len) {
 		written=readWord(buf,&buf[len],command,cmdlen);
 		if(!ChkAdvance(written,&buf,&len,"*** ERROR MotionSequence load corrupted - line %d\n",linenum)) return 0;
 		written=readWord(buf,&buf[len],arg1,arglen);
-		if(!ChkAdvance(written,&buf,&len,"*** ERROR MotionSequence load corrupted - line %d\n",linenum)) return 0;
-		written=readWord(buf,&buf[len],arg2,cmdlen);
+		if(written>0)
+			if(!ChkAdvance(written,&buf,&len,"*** ERROR MotionSequence load corrupted - line %d\n",linenum)) return 0;
+		written=readWord(buf,&buf[len],arg2,arglen);
 		if(written!=0)
 			if(!ChkAdvance(written,&buf,&len,"*** ERROR MotionSequence load corrupted - line %d\n",linenum)) return 0;
 		for(;len>0 && *buf!='\n';buf++,len--) {}
@@ -133,6 +135,10 @@ unsigned int MotionSequence::LoadBuffer(const char buf[], unsigned int len) {
 				overlayPose(pose);
 			else if(LoadFile(f.c_str())==0)
 				cout << "*** WARNING could not read file " << arg1 << " for overlay - line " << linenum << endl;
+		} else if(strcasecmp(command,"degrees")==0) {
+			setSaveDegrees();
+		} else if(strcasecmp(command,"radians")==0) {
+			setSaveRadians();
 		} else {
 			lastOutputIdx=getOutputIndex(command,lastOutputIdx+1);
 			if(lastOutputIdx==NumOutputs)
@@ -142,13 +148,15 @@ unsigned int MotionSequence::LoadBuffer(const char buf[], unsigned int len) {
 				double value=strtod(arg1,&used), weight=1;
 				if(*used!='\0')
 					cout << "*** WARNING illegal value argument: " << arg1 << " - line " << linenum << endl;
-				else if(arg2[0]!='\0') {
-					weight=strtod(arg2,&used);
-					if(*used!='\0') {
-						cout << "*** WARNING illegal weight argument: " << arg2 << " - line " << linenum << endl;
-						weight=1;
+				else {
+					if(arg2[0]!='\0') {
+						weight=strtod(arg2,&used);
+						if(*used!='\0') {
+							cout << "*** WARNING illegal weight argument: " << arg2 << " - line " << linenum << endl;
+							weight=1;
+						}
 					}
-					setOutputCmd(lastOutputIdx,OutputCmd(value,weight));
+					setOutputCmd(lastOutputIdx,OutputCmd(value*loadSaveMode,weight));
 				}
 			}
 		}
@@ -168,22 +176,29 @@ unsigned int MotionSequence::SaveBuffer(char buf[], unsigned int len) const {
 		cout << "*** ERROR MotionSequence save overflow on header" << endl;
 		return 0;
 	}
+	written=snprintf(buf,len,isSaveRadians()?"radians\n":"degrees\n");
+	if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR MotionSequence save failed on mode\n")) return 0;	if(len==0 || len>origlen) {
+		cout << "*** ERROR MotionSequence save overflow" << endl;
+		return 0;
+	}
 	unsigned int t=0;
 	Move_idx_t tprevs[NumOutputs];
 	Move_idx_t tnexts[NumOutputs];
 	for(unsigned int i=0;i<NumOutputs;i++)
 		tnexts[i]=getKeyFrame(tprevs[i]=starts[i]).next;
 	while(t!=-1U) {
-		//std::cout << "t="<<t<<"..."<<std::flush;
+//		std::cout << "t="<<t<<"..."<<std::flush;
 		for(unsigned int i=0; i<NumOutputs; i++) {
-			if(getKeyFrame(tprevs[i]).cmd.weight!=0 && getKeyFrame(tprevs[i]).starttime==t) {
+//			cout << i << ' ' << outputNames[i] << ' ' << getKeyFrame(tprevs[i]).cmd.value << ' ' << getKeyFrame(tprevs[i]).cmd.weight << ' ' << getKeyFrame(tprevs[i]).starttime << " state: " << starts[i] <<' '<< prevs[i] <<' '<< nexts[i] << " cur: " << getKeyFrame(tprevs[i]).prev << ' ' << tprevs[i] << ' ' << getKeyFrame(tprevs[i]).next << endl;
+			//first conditional is to skip 0 weighted values in first frame
+			if((t!=0 || getKeyFrame(tprevs[i]).cmd.weight!=0) && getKeyFrame(tprevs[i]).starttime==t) {
 				if(getKeyFrame(tprevs[i]).cmd.weight==1) {
 					if(t!=0) {
-						written=snprintf(buf,len,"%s\t%g\n",outputNames[i],getKeyFrame(tprevs[i]).cmd.value);
+						written=snprintf(buf,len,"%s\t%g\n",outputNames[i],getKeyFrame(tprevs[i]).cmd.value/loadSaveMode);
 						if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR MotionSequence save failed\n")) return 0;
 					}
 				} else {
-					written=snprintf(buf,len,"%s\t%g\t%g\n",outputNames[i],getKeyFrame(tprevs[i]).cmd.value,getKeyFrame(tprevs[i]).cmd.weight);
+					written=snprintf(buf,len,"%s\t%g\t%g\n",outputNames[i],getKeyFrame(tprevs[i]).cmd.value/loadSaveMode,getKeyFrame(tprevs[i]).cmd.weight);
 					if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR MotionSequence save failed\n")) return 0;
 				}
 				if(len==0 || len>origlen) {
@@ -220,12 +235,13 @@ void MotionSequence::setPlayTime(unsigned int x) {
 }
 
 void MotionSequence::setOutputCmd(unsigned int i, const OutputCmd& cmd) {
-	Move& prev_m=getKeyFrame(prevs[i]);
-	if(playtime==prev_m.starttime) { //edit current keyframe
-		prev_m.cmd=cmd;
+	Move& p_m=getKeyFrame(prevs[i]);
+	if(playtime==p_m.starttime) { //edit current keyframe
+		p_m.cmd=cmd;
 	} else { //add new keyframe
 		Move_idx_t x = newKeyFrame();
 		Move& cur=getKeyFrame(x);
+		Move& prev_m=getKeyFrame(prevs[i]); //it's important to refresh this - newKeyFrame may have invalidated p_m reference
 		cur.cmd=cmd;
 		cur.starttime=playtime;
 		cur.prev=prevs[i];
@@ -238,6 +254,7 @@ void MotionSequence::setOutputCmd(unsigned int i, const OutputCmd& cmd) {
 				endtime=playtime;
 		}
 		prevs[i]=x;
+//		cout << "set " << i << ' ' << outputNames[i] << ' ' << cur.cmd.value << ' ' << cur.cmd.weight << ' ' << cur.starttime << " state: " << starts[i] <<' '<< prevs[i] <<' '<< prev_m.next <<' '<< nexts[i] << " new: " << cur.prev << ' ' << x << ' ' << cur.next << endl;
 	}
 }
 
@@ -375,9 +392,9 @@ unsigned int MotionSequence::getOutputIndex(const char name[], unsigned int idx)
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2003/03/04 05:46:06 $
+ * $Date: 2003/04/25 22:25:40 $
  */
 
