@@ -3,6 +3,7 @@
 #define INCLUDED_MotionSequenceMC_h_
 
 #include "MotionCommand.h"
+#include "MotionManager.h"
 #include "Shared/LoadSave.h"
 #include "Shared/ListMemBuf.h"
 #include "PostureEngine.h"
@@ -43,21 +44,23 @@
  *  @verbatim
  *       First line: #MSq
  *  Zero or more of: delay <time-delta>              (moves playhead forward, in milliseconds)
- *               or: settime <time>                  (sets play time to specified value)
+ *               or: settime <time>                  (sets play time to specified value, in ms)
  *               or: <outputname> <value> [<weight>] (sets the specified output to the value - assumes 1 for weight)
  *               or: load <filename>                 (file is a posture, sets position)
  *               or: overlay <filename>              (file can be a posture or another motion sequence)
+ *               or: degrees                         (following <value>s will be interpreted as degrees [default])
+ *               or: radians                         (following <value>s will be interpreted as radians)
  *        Last line: #END
  *  @endverbatim
  *  After loading a motion sequence, the playtime is left at the end.
  *  This is to make it easy to append/overlay motion sequences
  *  
- *  Lines beginning with '#' are ignored.  Output names are found in RobotInfo.h, RobotInfo::outputNames.
+ *  Lines beginning with '#' are ignored.  Output names are defined in RobotInfo.h, RobotInfo::outputNames.
  */
 class MotionSequence : public MotionCommand, public LoadSave {
 public:
 	//!constructor, will start playing immediately
-	MotionSequence() : MotionCommand(), playtime(1), lasttime(0), endtime(0), playspeed(1.0), playing(true) {}
+	MotionSequence() : MotionCommand(), playtime(1), lasttime(0), endtime(0), playspeed(1.0), playing(true), loadSaveMode(M_PI/180) {}
 	//!destructor
 	virtual ~MotionSequence() {}
 
@@ -67,10 +70,14 @@ public:
 	virtual int isAlive() { return (playspeed>0) ? (playtime<=endtime) : (playtime>0); }
 	//@}
 	
-	//!@name Inherited from LoadSave
-	virtual unsigned int getBinSize() const; //!< returns the size used to save the sequence
-	virtual unsigned int LoadBuffer(const char buf[], unsigned int len); //!< doesn't clear before loading - call clear yourself if you want to reset, otherwise it will overlay.  Leaves playtime at end of load.
-	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const; //!< saves the motion sequence - will save a flat file - doesn't remember references to other files which were loaded
+	//!@name LoadSave related
+	virtual unsigned int getBinSize() const; //!< inherited, returns the size used to save the sequence
+	virtual unsigned int LoadBuffer(const char buf[], unsigned int len); //!< inherited, doesn't clear before loading - call clear yourself if you want to reset, otherwise it will overlay.  Leaves playtime at end of load.
+	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const; //!< inherited, saves the motion sequence - will save a flat file - doesn't remember references to other files which were loaded
+	void setSaveDegrees() { loadSaveMode=M_PI/180; }       //!< will store angles as degrees on future saves
+	bool isSaveDegrees() const { return loadSaveMode!=1; } //!< returns true if will store angles as degrees on future saves
+	void setSaveRadians() { loadSaveMode=1; }              //!< will store angles as radians on future saves
+	bool isSaveRadians() const { return loadSaveMode==1; } //!< returns true if will store angles as degrees on future saves
 	//@}
 	
 	//!@name Sequence Construction
@@ -92,8 +99,8 @@ public:
 	void resume();                                          //!< begins playback from the current playtime
 	unsigned int getPlayTime() const { return playtime; }   //!< returns the current position of the playback (in milliseconds), see setPlayTime()
 	unsigned int getEndTime() const { return endtime; }     //!< returns the length of the motion sequence (in milliseconds)
-	void setPlaySpeed(double x) { playspeed=x; }            //!< sets the playback speed (e.g. 1=regular, 0.5=half speed, -1=@b backwards)
-	double getPlaySpeed() const { return playspeed; }       //!< returns the playback speed
+	void setPlaySpeed(float x) { playspeed=x; }            //!< sets the playback speed (e.g. 1=regular, 0.5=half speed, -1=@b backwards)
+	float getPlaySpeed() const { return playspeed; }       //!< returns the playback speed
 	//@}
 
 protected:
@@ -120,8 +127,10 @@ protected:
 	unsigned int playtime;              //!< the current time of playback, 0 is start of sequence
 	unsigned int lasttime;              //!< the time of the last update
 	unsigned int endtime;               //!< max of #moves's Move::starttime's
-	double playspeed;                   //!< multiplies the difference between current time and starttime, negative will cause play backwards
+	float playspeed;                    //!< multiplies the difference between current time and starttime, negative will cause play backwards
 	bool playing;                       //!< true if playing, false if paused
+	
+	float loadSaveMode;                 //!< 1 to use radians, M_PI/180 for degrees during a save
 
 	virtual Move& getKeyFrame(Move_idx_t x) =0;            //!< returns the Move struct corresponding to @a x in the subclass's actual data structure
 	virtual const Move& getKeyFrame(Move_idx_t x) const=0; //!< returns the Move struct corresponding to @a x in the subclass's actual data structure
@@ -130,7 +139,7 @@ protected:
 
 	//!Does the actual calculation of position information.  Perhaps replace with a Bezier or spline or something?
 	void calcOutput(OutputCmd& ans, unsigned int t, const Move& prev, const Move& next) const {
-		double prevweight=(double)(next.starttime-t)/(double)(next.starttime-prev.starttime);
+		float prevweight=(float)(next.starttime-t)/(float)(next.starttime-prev.starttime);
 		ans.set(prev.cmd,next.cmd,prevweight);
 	}
 	
@@ -154,7 +163,7 @@ protected:
 };
 
 //! Instantiates MotionSequences - when you want to make a new MotionSequence, make one of these
-/*! Allows a variable amount of data storage through its template parameter.
+/*! Allows a (compile-time) variable amount of data storage through its template parameter.
  *  See MotionSequence for documentation on its members */
 template<unsigned int MAXMOVE>
 class MotionSequenceMC : public MotionSequence {
@@ -265,10 +274,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.4 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.5 $
  * $State: Exp $
- * $Date: 2003/03/04 05:46:06 $
+ * $Date: 2003/04/25 18:22:40 $
  */
 
 #endif
