@@ -117,7 +117,7 @@ float PostureEngine::maxdiff(const PostureEngine& pe) const {
 }
 
 unsigned int PostureEngine::getBinSize() const {
-	unsigned int len=10;
+	unsigned int len=11;
 	char buf[255];
 	for(unsigned int i=0; i<NumOutputs; i++)
 		if(cmds[i].weight>0)
@@ -129,11 +129,11 @@ unsigned int PostureEngine::LoadBuffer(const char buf[], unsigned int len) {
 	unsigned int origlen=len;
 	clear();
 	if(strncmp("#POS\n",buf,5)!=0) {
-		//		cout << "ERROR PostureEngine load corrupted - expected #POS header" << endl;
+		//		std::cout << "ERROR PostureEngine load corrupted - expected #POS header" << std::endl;
 		return 0;
 	}
 	char formatstring[64];
-	snprintf(formatstring,64,"%%%dc %%f %%f\n%%n",outputNameLen); //cout << "Format: " << formatstring << endl;
+	snprintf(formatstring,64,"%%%dc %%f %%f\n%%n",outputNameLen); //std::cout << "Format: " << formatstring << std::endl;
 	unsigned int idx=0;
 	unsigned int linenum=2;
 	char jname[outputNameLen+1];
@@ -154,7 +154,7 @@ unsigned int PostureEngine::LoadBuffer(const char buf[], unsigned int len) {
 		sscanf(buf,formatstring,jname,&fval,&fwht,&written);
 		if(!ChkAdvance(written,&buf,&len,"*** ERROR PostureEngine load corrupted - line %d\n",linenum)) return 0;
 		linenum++;
-		//cout << '"' << jname << "\"\t" << (float)fval << '\t' << (float)fwht << endl;
+		//std::cout << '"' << jname << "\"\t" << (float)fval << '\t' << (float)fwht << std::endl;
 		unsigned int startidx=idx+1;
 		for(;idx<NumOutputs;idx++)
 			if(strcmp(jname,outputNames[idx])==0) {
@@ -168,10 +168,10 @@ unsigned int PostureEngine::LoadBuffer(const char buf[], unsigned int len) {
 					break;
 			}
 			if(idx==startidx && strcmp(jname,outputNames[idx])!=0)
-				cout << "*** WARNING unmatched jointName: " << jname << endl;
+				std::cout << "*** WARNING unmatched jointName: " << jname << std::endl;
 		}
 	}
-	cout << "*** WARNING PostureEngine load missing #END" << endl;
+	std::cout << "*** WARNING PostureEngine load missing #END" << std::endl;
 	return origlen-len;
 }
 
@@ -181,7 +181,7 @@ unsigned int PostureEngine::SaveBuffer(char buf[], unsigned int len) const {
 	int written=snprintf(buf,len,"#POS\n");
 	if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR PostureEngine save failed on header\n")) return 0;
 	if(len==0 || len>origlen) {
-		cout << "*** ERROR PostureEngine save overflow on header" << endl;
+		std::cout << "*** ERROR PostureEngine save overflow on header" << std::endl;
 		return 0;
 	}
 	for(unsigned int i=0; i<NumOutputs; i++)
@@ -189,14 +189,14 @@ unsigned int PostureEngine::SaveBuffer(char buf[], unsigned int len) const {
 			written=snprintf(buf,len,"%s\t% .4f\t% .4f\n",outputNames[i],cmds[i].value,cmds[i].weight);
 			if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR PostureEngine save failed\n")) return 0;
 			if(len==0 || len>origlen) {
-				cout << "*** ERROR PostureEngine save overflow" << endl;
+				std::cout << "*** ERROR PostureEngine save overflow" << std::endl;
 				return 0;
 			}
 		}
 	written=snprintf(buf,len,"#END\n");
 	if(!ChkAdvance(written,(const char**)&buf,&len,"*** ERROR PostureEngine save failed on #END\n")) return 0;
 	if(len==0 || len>origlen) {
-		cout << "*** ERROR PostureEngine save overflow on #END" << endl;
+		std::cout << "*** ERROR PostureEngine save overflow on #END" << std::endl;
 		return 0;
 	}
 	return origlen-len;
@@ -229,9 +229,9 @@ bool PostureEngine::ChkAdvance(int res, const char** buf, unsigned int* len, con
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.7 $
  * $State: Exp $
- * $Date: 2003/03/04 05:46:07 $
+ * $Date: 2003/04/30 03:55:54 $
  */
 
