@@ -98,6 +98,8 @@ void Config::readConfig(const char* filename) {
 					main.wsjoints_port=atoi(value);
 				} else if (strncasecmp(key,"wspids_port",29)==0) {
 					main.wspids_port=atoi(value);
+				} else if (strncasecmp(key,"mecha_port",29)==0) {
+					main.mecha_port=atoi(value);
 				}
 				break;
 			case sec_behaviors:
@@ -116,7 +118,7 @@ void Config::readConfig(const char* filename) {
 				break;
 			case sec_motion:
 				if (strncasecmp(key,"root",29)==0)
-					strncpy(motion.root,value,49);
+					motion.root=value;
 				else if (strncasecmp(key,"estop_on_snd",29)==0)
 					strncpy(motion.estop_on_snd,value,49);
 				else if (strncasecmp(key,"estop_off_snd",29)==0)
@@ -134,7 +136,7 @@ void Config::readConfig(const char* filename) {
 				break;
 			case sec_sound:
 				if (strncasecmp(key,"root",29)==0)
-					strncpy(sound.root,value,49);
+					sound.root=value;
 				else if (strncasecmp(key,"sample_rate",29)==0)
 					sound.sample_rate = atoi(value);
 				else if (strncasecmp(key,"sample_bits",29)==0)
