@@ -61,11 +61,12 @@ class Config {
 		int verbose_level; //!< controls verbosity of info
 		int wsjoints_port; //!< port to send joint positions on
 		int wspids_port;   //!< port to send pid info on
+		int mecha_port;	   //!< port for receiving mecha commands
 
 		//!constructor
 		main_config()
 			: console_port(0), stderr_port(0), error_level(0), debug_level(0),
-				 verbose_level(0),wsjoints_port(0),wspids_port(0)
+				 verbose_level(0),wsjoints_port(0),wspids_port(0),mecha_port(0)
 		{ }
 	} main;
 
@@ -89,10 +90,17 @@ class Config {
     
 	//!motion information
 	struct motion_config {
-		char root[50]; //!< path on memory stick to "motion" files - for instance, position (.pos) and motion sequence (.mot)
+		std::string root;       //!< path on memory stick to "motion" files - for instance, position (.pos) and motion sequence (.mot)
 		char estop_on_snd[50];  //!< sound file to use when e-stop turned on
 		char estop_off_snd[50]; //!< sound file to use when e-stop turned off
-		motion_config() {
+
+		//!returns an absolute path if @a is relative (to root), otherwise just @a name
+		std::string makePath(std::string name) { 
+			return (name[0]!='/')?root+"/"+name:name;
+		}
+
+		//!constructor
+		motion_config() : root() {
 			estop_on_snd[0]=estop_off_snd[0]='\0';
 		}
 	} motion;
@@ -109,13 +117,18 @@ class Config {
 	
 	//!sound information
 	struct sound_config {
-		char root[50]; //!< path to sound clips
+		std::string root;         //!< path to sound clips
 		unsigned int sample_rate; //!< sample rate to send to system, currently only 8000 or 16000 supported
 		unsigned int sample_bits; //!< sample bit depth, either 8 or 16
 		std::vector<std::string> preload; //!< list of sounds to preload at boot
 			
+		//!returns an absolute path if @a is relative (to root), otherwise just @a name
+		std::string makePath(std::string name) { 
+			return (name[0]!='/')?root+"/"+name:name;
+		}
+
 		//!constructor
-		sound_config() : sample_rate(0), sample_bits(0), preload() {}
+		sound_config() : root(), sample_rate(0), sample_bits(0), preload() {}
 	} sound;
 
 	//! call this function when it's time to read the configuration file
@@ -130,10 +143,10 @@ extern Config* config;
  * @author alokl (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.9 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.11 $
  * $State: Exp $
- * $Date: 2003/04/09 04:48:18 $
+ * $Date: 2003/04/25 22:25:43 $
  */
 
 #endif
