@@ -1,9 +1,11 @@
+#ifdef PLATFORM_APERIOS
 #include <OPENR/core_macro.h>
 #include <OPENR/ObjcommTypes.h>
 #include <OPENR/OPENR.h>
 #include <OPENR/OPENRAPI.h>
 #include <OPENR/OPENRMessages.h>
 #include <OPENR/OPower.h>
+#endif
 
 #include "WorldState.h"
 #include "Shared/get_time.h"
@@ -22,7 +24,11 @@ WorldState * state=NULL;
 WorldState::WorldState()
 	: alwaysGenerateStatus(false), robotStatus(0), batteryStatus(0),
 		lastSensorUpdateTime(0), mainProfile(), motionProfile(),
-    wsser(NULL), curtime(get_time()) {
+#ifdef PLATFORM_APERIOS
+		wsser(NULL), 
+#endif
+		curtime(get_time())
+	{
 	for(unsigned int i=0; i< NumOutputs; i++)
 		outputs[i]=0;
 	for(unsigned int i=0; i< NumButtons; i++)
@@ -36,9 +42,12 @@ WorldState::WorldState()
 		pidduties[i]=0;
 	memset(powerFlags,0,sizeof(unsigned int)*PowerSourceID::NumPowerSIDs);
 	memset(button_times,0,sizeof(unsigned int)*NumButtons);
-  wsser=new WorldStateSerializer();
+#ifdef PLATFORM_APERIOS
+	wsser=new WorldStateSerializer();
+#endif
 }
 
+#ifdef PLATFORM_APERIOS
 
 /*! This will cause events to be posted
  *  @todo change to use most recent instead of oldest - is a buffer! */
@@ -81,6 +90,7 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
   pidduties[HeadOffset+PanOffset ] = GETDUTY(CPCJointNeckPan);
   pidduties[HeadOffset+RollOffset] = GETDUTY(CPCJointNeckRoll);
 
+#if 0
 	outputs[TailOffset+TiltOffset] = GETD(CPCJointTailTilt);
 	outputs[TailOffset+PanOffset]  = GETD(CPCJointTailPan);
 	pidduties[TailOffset+TiltOffset] = GETDUTY(CPCJointTailTilt);
@@ -88,7 +98,12 @@ void WorldState::read(OSensorFrameVectorData& sensor, EventRouter* er) {
 
 	outputs[MouthOffset] = GETD(CPCJointMouth);
 	pidduties[MouthOffset] = GETDUTY(CPCJointMouth);
+#endif
 
+// (ERS-220 only) This is a pseudo code, and is not implemented yet.
+// 	chkEvent(er, LBkButOffset, GETB(CPCSensorTailLeftSwitch),  "LBkBut");
+// 	chkEvent(er, CBkButOffset, GETB(CPCSensorTailCenterSwitch),"CBkBut");
+// 	chkEvent(er, RBkButOffset, GETB(CPCSensorTailRightSwitch), "RBkBut");
 
   // Get foot switches
 	chkEvent(er,LFrPawOffset,GETB(CPCSensorLFPaw),"LFrPaw");
@@ -190,6 +205,8 @@ void WorldState::read(const OPowerStatus& power, EventRouter* er) {
 	er->postEvent(EventBase::powerEGID,PowerSourceID::UpdatedSID,EventBase::statusETID,0);
 }
 
+#endif //PLATFORM_APERIOS
+
 void WorldState::chkEvent(EventRouter* er, unsigned int off, float newval, const char* name) {
 	ButtonSourceID::ButtonSourceID_t sid=static_cast<ButtonSourceID::ButtonSourceID_t>(off); //should be a direct conversion
 	if(newval>=0.1) { //now on
@@ -216,8 +233,8 @@ void WorldState::chkEvent(EventRouter* er, unsigned int off, float newval, const
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2003/03/03 01:18:14 $
+ * $Date: 2003/04/27 23:57:43 $
  */
