@@ -2,20 +2,24 @@
 #ifndef INCLUDED_WorldState_h
 #define INCLUDED_WorldState_h
 
+#ifdef PLATFORM_APERIOS
 #include <OPENR/core_macro.h>
 #include <OPENR/ObjcommTypes.h>
 #include <OPENR/OPENR.h>
 #include <OPENR/OPENRAPI.h>
 #include <OPENR/OPENRMessages.h>
+#endif
 
 #include "Shared/RobotInfo.h"
 #include "Events/EventBase.h"
 #include "Shared/Profiler.h"
 #include <math.h>
+
+#ifdef PLATFORM_APERIOS
 #include "WorldStateSerializer.h"
+#endif
 
 class EventRouter;
-class WorldStateSerializer;
 
 //The following SourceIDs are for events created by WorldState's event generators
 
@@ -137,16 +141,18 @@ public:
 	
 	unsigned int lastSensorUpdateTime;     //!<primarily so calcDers can determine the time difference between updates, but others might want to know this too...
 
-  static const double g;                 //!< the gravitational acceleration of objects on earth
+	static const double g;                 //!< the gravitational acceleration of objects on earth
 	static const double IROORDist;         //!< If IR returns this, we're out of range
 
 	ProfilerOfSize<20> mainProfile;        //!< holds code profiling information for MainObject
 	ProfilerOfSize<06> motionProfile;      //!< holds code profiling information for MotionObject
 
-  void read(OSensorFrameVectorData& sensor, EventRouter* er); //!< will process a sensor reading as given by OPEN-R
+#ifdef PLATFORM_APERIOS
+	void read(OSensorFrameVectorData& sensor, EventRouter* er); //!< will process a sensor reading as given by OPEN-R
 	void read(const OPowerStatus& power, EventRouter* er);      //!< will process a power status update as given by OPEN-R
 
-  WorldStateSerializer * wsser; //!< sends current worldstate to TekkotsuMon, if it's connected
+	WorldStateSerializer * wsser; //!< sends current worldstate to TekkotsuMon, if it's connected
+#endif
 
 protected:
 	unsigned int curtime; //!< set by read(OSensorFrameVectorData& sensor, EventRouter* er) for chkEvent() so each call doesn't have to
@@ -182,41 +188,6 @@ protected:
 		acc=diff*invtimediff;
 	}
 
-	/*! @name CPC IDs
-	 * used to interface with lower level OPEN-R code to read sensors - DOESN'T correspond to ::PrimitiveName */
-	static const int CPCJointNeckTilt           =  0; //!< Head
-	static const int CPCJointNeckPan            =  1;
-	static const int CPCJointNeckRoll           =  2;
-	static const int CPCSensorHeadBackPressure  =  3;
-	static const int CPCSensorHeadFrontPressure =  4;
-	static const int CPCSensorPSD               =  5;
-	static const int CPCJointMouth              =  6;
-	static const int CPCSensorChinSwitch        =  7;
-	static const int CPCJointLFRotator          =  8; //!< Left front leg
-	static const int CPCJointLFElevator         =  9;
-	static const int CPCJointLFKnee             = 10;
-	static const int CPCSensorLFPaw             = 11;
-	static const int CPCJointLHRotator          = 12; //!< Left hind leg
-	static const int CPCJointLHElevator         = 13;
-	static const int CPCJointLHKnee             = 14;
-	static const int CPCSensorLHPaw             = 15;
-	static const int CPCJointRFRotator          = 16; //!< Right front leg
-	static const int CPCJointRFElevator         = 17;
-	static const int CPCJointRFKnee             = 18;
-	static const int CPCSensorRFPaw             = 19;
-	static const int CPCJointRHRotator          = 20; //!< Right hind leg
-	static const int CPCJointRHElevator         = 21;
-	static const int CPCJointRHKnee             = 22;
-	static const int CPCSensorRHPaw             = 23;
-	static const int CPCJointTailPan            = 24; //!< Tail
-	static const int CPCJointTailTilt           = 25;
-	static const int CPCSensorThermoSensor      = 26;
-	static const int CPCSensorBackSwitch        = 27;
-	static const int CPCSensorAccelFB           = 28; //!< Front-back @see RobotInfo::BAccelOffset 
-	static const int CPCSensorAccelLR           = 29; //!< Left-right @see RobotInfo::LAccelOffset 
-	static const int CPCSensorAccelUD           = 30; //!< Up-down  @see RobotInfo::DAccelOffset 
-	//@}
-
 private:
 	WorldState(const WorldState&); //!< don't use
 	WorldState operator=(const WorldState&); //!< don't use
@@ -229,10 +200,10 @@ extern WorldState * state; //!< the global state object, is a shared memory regi
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.13 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.15 $
  * $State: Exp $
- * $Date: 2003/04/09 04:48:19 $
+ * $Date: 2003/04/27 23:57:43 $
  */
 
 #endif
