@@ -562,7 +562,7 @@ SoundManager::makePath(const char* name, char tmp[MAX_NAME_LEN]) {
 	const char* path=name;
 	if(name[0]!='/') {
 		path=tmp;
-		strncpy(tmp,config->sound.root,MAX_NAME_LEN);
+		strncpy(tmp,config->sound.root.c_str(),MAX_NAME_LEN);
 		strncat(tmp,"/",MAX_NAME_LEN);
 		strncat(tmp,name,MAX_NAME_LEN);
 	}
@@ -688,10 +688,10 @@ SoundManager::PlayState::PlayState()
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-1_1 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-1_2 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2003/04/09 03:33:57 $
+ * $Date: 2003/04/25 22:25:43 $
  */
 
 
