@@ -6,14 +6,14 @@
 #include "Behaviors/Controls/BatteryCheckControl.h"
 #include "Behaviors/Controls/BehaviorActivatorControl.h"
 #include "Behaviors/Controls/BehaviorSwitchControl.h"
-//#include "Behaviors/Controls/LoadAIControl.h"
+#include "Behaviors/Controls/FileBrowserControl.h"
 #include "Behaviors/Controls/LoadPostureControl.h"
 #include "Behaviors/Controls/LoadWalkControl.h"
 #include "Behaviors/Controls/MenuControl.h"
 #include "Behaviors/Controls/MCValueEditControl.h"
+#include "Behaviors/Controls/PlaySoundControl.h"
 #include "Behaviors/Controls/ProfilerCheckControl.h"
 #include "Behaviors/Controls/RunSequenceControl.h"
-//#include "Behaviors/Controls/SaveAIControl.h"
 #include "Behaviors/Controls/SavePostureControl.h"
 #include "Behaviors/Controls/SaveWalkControl.h"
 #include "Behaviors/Controls/ValueEditControl.h"
@@ -21,13 +21,12 @@
 
 #include "Behaviors/Controls/EventLogger.h"
 
+#include "Behaviors/Demos/AutoGetupBehavior.h"
 #include "Behaviors/Demos/BatteryMonitorBehavior.h"
-//#include "Behaviors/Demos/CameraBehavior.h"
 #include "Behaviors/Demos/ChaseBallBehavior.h"
 #include "Behaviors/Demos/StareAtBallBehavior.h"
 #include "Behaviors/Demos/FollowHeadBehavior.h"
 #include "Behaviors/Demos/HeadLevelBehavior.h"
-//#include "Behaviors/Demos/XORBehavior.h"
 #include "Behaviors/Demos/EvtRptBehavior.h"
 
 #include "Behaviors/Demos/PaceTargetsMachine.h"
@@ -36,6 +35,7 @@
 #include "Behaviors/Demos/WorldModel2Behavior.h"
 #include "Behaviors/Demos/DumbWM2Behavior.h"
 #include "Behaviors/Demos/SoundTestBehavior.h"
+#include "Behaviors/Demos/MechaControllerBehavior.h"
 
 #include "Motion/MotionCommand.h"
 #include "Motion/PostureMC.h"
@@ -156,9 +156,11 @@ StartupBehavior::SetupController(Controller& controller) {
 		mcsetup.top()->pushSlot(new MenuControl("Background Behaviors"));
 		{ 
 			mcsetup.push((MenuControl*)mcsetup.top()->getSlots().back());
+			mcsetup.top()->pushSlot((new BehaviorSwitchControl<AutoGetupBehavior>("Auto Getup",false))->start());
 			mcsetup.top()->pushSlot((new BehaviorSwitchControl<BatteryMonitorBehavior>("Battery Monitor",false))->start());
 			mcsetup.top()->pushSlot(new BehaviorSwitchControl<EvtRptBehavior>("EvtRptBehavior",false));
 			mcsetup.top()->pushSlot(new BehaviorSwitchControl<DumbWM2Behavior>("DumbWM2Behavior",false));
+			mcsetup.top()->pushSlot(new BehaviorSwitchControl<MechaControllerBehavior>("MechaController",false));
 			
 			HeadLevelBehavior* levelbeh=new HeadLevelBehavior();
 			mcsetup.top()->pushSlot(new BehaviorSwitchControl<HeadLevelBehavior>("Head Level",levelbeh,NULL));
@@ -169,9 +171,11 @@ StartupBehavior::SetupController(Controller& controller) {
 		mcsetup.top()->pushSlot(new ProfilerCheckControl());
 		mcsetup.top()->pushSlot(new EventLogger());
 		
-		mcsetup.top()->pushSlot(new LoadPostureControl("Load Posture"));
+		mcsetup.top()->pushSlot(new LoadPostureControl("Load Posture",stop_id));
 		mcsetup.top()->pushSlot(new SavePostureControl("Save Posture"));
-		mcsetup.top()->pushSlot(new RunSequenceControl<255>("Run Motion Sequence"));
+		mcsetup.top()->pushSlot(new RunSequenceControl<500>("Run Motion Sequence",stop_id));
+		mcsetup.top()->pushSlot(new PlaySoundControl("Play Sound"));
+		mcsetup.top()->pushSlot(new FileBrowserControl("Files","/"));
 	}
 	if(mcsetup.size()!=1)
 		cout << "*** WARNING *** menu setup stack more than one or empty" << endl;
